package com.boman.system.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.boman.system.mapper.StandardlyMapper;
import com.boman.system.service.IBaseSelectService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

import static com.boman.common.core.utils.obj.ObjectUtils.requireNonNull;

/**
 * @author shiqian
 * @date 2021年03月29日 10:22
 **/
@Service
public class BaseSelectServiceImpl implements IBaseSelectService {

    private static final Logger LOGGER = LoggerFactory.getLogger(BaseSelectServiceImpl.class);

    @Autowired
    private StandardlyMapper mapper;


    /**
     * 功能描述: 根据条件查询
     *
     * @param tableName     tableName
     * @param condition     原始查询条件
     * @param packCondition 封装的查询条件
     * @param showData      前台需要查询的列
     * @param orderBy       orderBy
     * @param limit         分页
     * @param offset        分页
     * @return java.util.List<com.alibaba.fastjson.JSONObject>
     */
    @Override
    public List<JSONObject> selectByCondition(String tableName, JSONObject condition
            , JSONObject packCondition, JSONArray showData, String orderBy, Integer limit, Integer offset) {
        requireNonNull(tableName);
//        requireNonNull(showData);
        requireNonNull(limit);
        requireNonNull(orderBy);
        return mapper.selectByCondition(tableName, condition, packCondition, showData, orderBy, limit, offset);
    }

    /**
     * 功能描述: 根据条件查询
     *
     * @param tableName     tableName
     * @param condition     原始查询条件
     * @param packCondition 封装的查询条件
     * @return int
     */
    @Override
    public int countByCondition(String tableName, JSONObject condition, JSONObject packCondition) {
        requireNonNull(tableName);
        return mapper.countByCondition(tableName, condition, packCondition);
    }

    /**
     * 功能描述: 根据id查所有，不支持自定义查询列
     *
     * @param tableName 表名
     * @param pkName    主键名称
     * @param id        主键值
     * @return com.alibaba.fastjson.JSONObject
     */
    @Override
    public JSONObject selectById(String tableName, String pkName, Long id) {
        requireNonNull(tableName);
        requireNonNull(pkName);
        requireNonNull(id);
        return mapper.selectById(tableName, pkName, id);
    }
}
